@@ -5,23 +5,26 @@ import json
 from django.contrib import messages
 from django.contrib.auth.decorators import login_required
 from django.contrib.messages.storage.base import Message
-from django.http import HttpResponse, HttpResponseBadRequest, HttpResponseServerError
+from django.http import (
+    HttpResponse,
+    HttpResponseBadRequest,
+    HttpResponseServerError,
+)
 from django.urls import reverse
 from django.utils.html import escape
 
 import core_main_app.components.data.api as data_api
-import core_main_app.components.user.api as user_api
 import core_main_app.components.template.api as template_api
-from core_dashboard_common_app import constants
-from core_main_app.access_control.exceptions import AccessControlError
-from core_main_app.commons.exceptions import DoesNotExist, ModelError
-from core_main_app.components.blob import api as blob_api
+import core_main_app.components.user.api as user_api
 from core_explore_common_app.components.abstract_persistent_query import (
     api as persistent_query_api,
 )
 from core_explore_common_app.components.abstract_persistent_query.models import (
     AbstractPersistentQuery,
 )
+from core_main_app.access_control.exceptions import AccessControlError
+from core_main_app.commons.exceptions import DoesNotExist, ModelError
+from core_main_app.components.blob import api as blob_api
 from core_main_app.components.lock import api as lock_api
 from core_main_app.components.workspace import api as workspace_api
 from core_main_app.settings import INSTALLED_APPS
@@ -32,9 +35,12 @@ if "core_curate_app" in INSTALLED_APPS:
         CurateDataStructure,
     )
     import core_curate_app.components.curate_data_structure.api as curate_data_structure_api
+from core_dashboard_common_app import constants
 
 
-def _check_rights_document(request_user_is_superuser, request_user_id, document_user):
+def _check_rights_document(
+    request_user_is_superuser, request_user_id, document_user
+):
     """Check if the user is superuser or if the document belongs to the user.
 
     Args:
@@ -44,7 +50,9 @@ def _check_rights_document(request_user_is_superuser, request_user_id, document_
 
     Returns:
     """
-    if not request_user_is_superuser and str(request_user_id) != str(document_user):
+    if not request_user_is_superuser and str(request_user_id) != str(
+        document_user
+    ):
         raise Exception("You don't have the rights to perform this action.")
 
 
@@ -68,9 +76,11 @@ def _get_workspaces(workspace_ids, request_user_is_superuser, request_user_id):
 
             list_workspaces.append(workspace)
     except DoesNotExist:
-        raise Exception("It seems a workspace is missing. Please refresh the page.")
-    except Exception as e:
-        raise Exception(str(e))
+        raise Exception(
+            "It seems a workspace is missing. Please refresh the page."
+        )
+    except Exception as exception:
+        raise Exception(str(exception))
 
     return list_workspaces
 
@@ -99,8 +109,8 @@ def _get_blobs(blob_ids, user):
             list_blobs.append(blob)
     except DoesNotExist:
         raise Exception("It seems a blob is missing. Please refresh the page.")
-    except Exception as e:
-        raise Exception(str(e))
+    except Exception as exception:
+        raise Exception(str(exception))
 
     return list_blobs
 
@@ -125,10 +135,12 @@ def _get_forms(form_ids, user):
             list_form.append(form)
     except DoesNotExist:
         raise Exception(
-            "It seems a " + get_form_label() + " is missing. Please refresh the page."
+            "It seems a "
+            + get_form_label()
+            + " is missing. Please refresh the page."
         )
-    except Exception as e:
-        raise Exception(str(e))
+    except Exception as exception:
+        raise Exception(str(exception))
 
     return list_form
 
@@ -152,15 +164,19 @@ def _get_data(data_ids, user):
             data = data_api.get_by_id(data_id, user)
 
             # Check the rights
-            _check_rights_document(user.is_superuser, str(user.id), data.user_id)
+            _check_rights_document(
+                user.is_superuser, str(user.id), data.user_id
+            )
 
             data_table.append(data)
     except DoesNotExist:
         raise Exception(
-            "It seems a " + get_data_label() + " is missing. Please refresh the page."
+            "It seems a "
+            + get_data_label()
+            + " is missing. Please refresh the page."
         )
-    except Exception as e:
-        raise Exception(str(e))
+    except Exception as exception:
+        raise Exception(str(exception))
 
     return data_table
 
@@ -185,13 +201,17 @@ def _get_query(query_type, query_ids, user):
             query = persistent_query_api.get_by_id(query_type, query_id, user)
 
             # Check the rights
-            _check_rights_document(user.is_superuser, str(user.id), query.user_id)
+            _check_rights_document(
+                user.is_superuser, str(user.id), query.user_id
+            )
 
             query_table.append(query)
     except DoesNotExist:
-        raise Exception("It seems a query is missing. Please refresh the page.")
-    except Exception as e:
-        raise Exception(str(e))
+        raise Exception(
+            "It seems a query is missing. Please refresh the page."
+        )
+    except Exception as exception:
+        raise Exception(str(exception))
 
     return query_table
 
@@ -216,16 +236,18 @@ def delete_document(request):
 
     if document == constants.FUNCTIONAL_OBJECT_ENUM.RECORD.value:
         return _delete_record(request, document_ids)
-    elif document == constants.FUNCTIONAL_OBJECT_ENUM.FORM.value:
+    if document == constants.FUNCTIONAL_OBJECT_ENUM.FORM.value:
         return _delete_form(request, document_ids)
-    elif document == constants.FUNCTIONAL_OBJECT_ENUM.FILE.value:
+    if document == constants.FUNCTIONAL_OBJECT_ENUM.FILE.value:
         return _delete_file(request, document_ids)
-    elif document == constants.FUNCTIONAL_OBJECT_ENUM.QUERY.value:
+    if document == constants.FUNCTIONAL_OBJECT_ENUM.QUERY.value:
         return _delete_query(request, document_ids)
-    elif document == constants.FUNCTIONAL_OBJECT_ENUM.WORKSPACE.value:
+    if document == constants.FUNCTIONAL_OBJECT_ENUM.WORKSPACE.value:
         return _delete_workspace(request, document_ids)
 
-    return HttpResponseBadRequest({"Bad entries. Please check the parameters."})
+    return HttpResponseBadRequest(
+        {"Bad entries. Please check the parameters."}
+    )
 
 
 def _delete_workspace(request, workspace_ids):
@@ -241,9 +263,11 @@ def _delete_workspace(request, workspace_ids):
         list_workspaces = _get_workspaces(
             workspace_ids, request.user.is_superuser, request.user.id
         )
-    except Exception as e:
-        messages.add_message(request, messages.INFO, str(e))
-        return HttpResponse(json.dumps({}), content_type="application/javascript")
+    except Exception as exception:
+        messages.add_message(request, messages.INFO, str(exception))
+        return HttpResponse(
+            json.dumps({}), content_type="application/javascript"
+        )
 
     try:
         for workspace in list_workspaces:
@@ -265,15 +289,19 @@ def _delete_file(request, blob_ids):
     """
     try:
         list_blob = _get_blobs(blob_ids, request.user)
-    except Exception as e:
-        messages.add_message(request, messages.INFO, str(e))
-        return HttpResponse(json.dumps({}), content_type="application/javascript")
+    except Exception as exception:
+        messages.add_message(request, messages.INFO, str(exception))
+        return HttpResponse(
+            json.dumps({}), content_type="application/javascript"
+        )
 
     try:
         for blob in list_blob:
             blob_api.delete(blob, request.user)
-        messages.add_message(request, messages.INFO, "File deleted with success.")
-    except:
+        messages.add_message(
+            request, messages.INFO, "File deleted with success."
+        )
+    except Exception:
         messages.add_message(
             request, messages.INFO, "A problem occurred while deleting."
         )
@@ -292,9 +320,11 @@ def _delete_form(request, form_ids):
     """
     try:
         list_form = _get_forms(form_ids, request.user)
-    except Exception as e:
-        messages.add_message(request, messages.INFO, str(e))
-        return HttpResponse(json.dumps({}), content_type="application/javascript")
+    except Exception as exception:
+        messages.add_message(request, messages.INFO, str(exception))
+        return HttpResponse(
+            json.dumps({}), content_type="application/javascript"
+        )
 
     try:
         for form in list_form:
@@ -304,7 +334,7 @@ def _delete_form(request, form_ids):
             messages.INFO,
             get_form_label().capitalize() + " deleted with success.",
         )
-    except:
+    except Exception:
         messages.add_message(
             request, messages.INFO, "A problem occurred while deleting."
         )
@@ -324,9 +354,11 @@ def _delete_record(request, data_ids):
 
     try:
         list_data = _get_data(data_ids, request.user)
-    except Exception as e:
-        messages.add_message(request, messages.INFO, str(e))
-        return HttpResponse(json.dumps({}), content_type="application/javascript")
+    except Exception as exception:
+        messages.add_message(request, messages.INFO, str(exception))
+        return HttpResponse(
+            json.dumps({}), content_type="application/javascript"
+        )
 
     try:
         for data in list_data:
@@ -334,7 +366,9 @@ def _delete_record(request, data_ids):
             if lock_api.is_object_locked(data.id, request.user):
                 message = Message(
                     messages.ERROR,
-                    "The " + get_data_label() + " is locked. You can't edit it.",
+                    "The "
+                    + get_data_label()
+                    + " is locked. You can't edit it.",
                 )
                 return HttpResponseBadRequest(
                     json.dumps({"message": message.message}),
@@ -347,7 +381,7 @@ def _delete_record(request, data_ids):
             messages.INFO,
             get_data_label().capitalize() + " deleted with success.",
         )
-    except:
+    except Exception:
         messages.add_message(
             request, messages.INFO, "A problem occurred while deleting."
         )
@@ -380,11 +414,15 @@ def _delete_query(request, query_ids):
         )
 
         # Get the persistent queries
-        list_query = _get_query(persistent_query_class, query_ids, request.user)
+        list_query = _get_query(
+            persistent_query_class, query_ids, request.user
+        )
 
-    except Exception as e:
-        messages.add_message(request, messages.INFO, str(e))
-        return HttpResponse(json.dumps({}), content_type="application/javascript")
+    except Exception as exception:
+        messages.add_message(request, messages.INFO, str(exception))
+        return HttpResponse(
+            json.dumps({}), content_type="application/javascript"
+        )
 
     try:
         for query in list_query:
@@ -395,7 +433,7 @@ def _delete_query(request, query_ids):
             messages.INFO,
             " Query deleted with success.",
         )
-    except:
+    except Exception:
         messages.add_message(
             request, messages.INFO, "A problem occurred while deleting."
         )
@@ -424,18 +462,21 @@ def change_owner_document(request):
         document_ids = request.POST.getlist("document_id[]", [])
         if len(document_ids) > 1 and not request.user.is_superuser:
             return HttpResponseServerError(
-                {"You don't have the rights to perform this action."}, status=403
+                {"You don't have the rights to perform this action."},
+                status=403,
             )
 
         if document == constants.FUNCTIONAL_OBJECT_ENUM.RECORD.value:
             return _change_owner_record(request, document_ids, user_id)
-        elif document == constants.FUNCTIONAL_OBJECT_ENUM.FORM.value:
+        if document == constants.FUNCTIONAL_OBJECT_ENUM.FORM.value:
             return _change_owner_form(request, document_ids, user_id)
-        elif document == constants.FUNCTIONAL_OBJECT_ENUM.FILE.value:
+        if document == constants.FUNCTIONAL_OBJECT_ENUM.FILE.value:
             return _change_owner_file(request, document_ids, user_id)
 
     else:
-        return HttpResponseBadRequest({"Bad entries. Please check the parameters."})
+        return HttpResponseBadRequest(
+            {"Bad entries. Please check the parameters."}
+        )
 
     return HttpResponse(json.dumps({}), content_type="application/javascript")
 
@@ -452,15 +493,26 @@ def _change_owner_form(request, form_ids, user_id):
     """
     try:
         list_form = _get_forms(form_ids, request.user)
-    except Exception as e:
-        return HttpResponseBadRequest(escape(str(e)))
+    except Exception as exception:
+        return HttpResponseBadRequest(escape(str(exception)))
 
     try:
         new_user = user_api.get_user_by_id(user_id)
+        failed_draft = 0
         for form in list_form:
-            curate_data_structure_api.change_owner(form, new_user, request.user)
-    except Exception as e:
-        return HttpResponseBadRequest(escape(str(e)))
+            try:
+                curate_data_structure_api.change_owner(
+                    form, new_user, request.user
+                )
+            except Exception:
+                failed_draft += 1
+        if failed_draft > 0:
+            error_message = (
+                f"Unable to change owner for {failed_draft} document(s)"
+            )
+            messages.add_message(request, messages.WARNING, error_message)
+    except Exception as exception:
+        return HttpResponseBadRequest(escape(str(exception)))
 
     return HttpResponse(json.dumps({}), content_type="application/javascript")
 
@@ -478,14 +530,14 @@ def _change_owner_record(request, data_ids, user_id):
     """
     try:
         list_data = _get_data(data_ids, request.user)
-    except Exception as e:
-        return HttpResponseBadRequest(escape(str(e)))
+    except Exception as exception:
+        return HttpResponseBadRequest(escape(str(exception)))
     try:
         new_user = user_api.get_user_by_id(user_id)
         for data in list_data:
             data_api.change_owner(data, new_user, request.user)
-    except Exception as e:
-        return HttpResponseBadRequest(escape(str(e)))
+    except Exception as exception:
+        return HttpResponseBadRequest(escape(str(exception)))
 
     return HttpResponse(json.dumps({}), content_type="application/javascript")
 
@@ -502,14 +554,14 @@ def _change_owner_file(request, blob_ids, user_id):
     """
     try:
         list_blob = _get_blobs(blob_ids, request.user)
-    except Exception as e:
-        return HttpResponseBadRequest(escape(str(e)))
+    except Exception as exception:
+        return HttpResponseBadRequest(escape(str(exception)))
     try:
         new_user = user_api.get_user_by_id(user_id)
         for blob in list_blob:
             blob_api.change_owner(blob, new_user, request.user)
-    except Exception as e:
-        return HttpResponseBadRequest(escape(str(e)))
+    except Exception as exception:
+        return HttpResponseBadRequest(escape(str(exception)))
 
     return HttpResponse(json.dumps({}), content_type="application/javascript")
 
@@ -528,7 +580,9 @@ def edit_record(request):
     except DoesNotExist:
         message = Message(
             messages.ERROR,
-            "It seems a " + get_data_label() + " is missing. Please refresh the page.",
+            "It seems a "
+            + get_data_label()
+            + " is missing. Please refresh the page.",
         )
         return HttpResponseBadRequest(
             json.dumps({"message": message.message, "tags": message.tags}),
@@ -538,7 +592,8 @@ def edit_record(request):
     # Check if the data is locked
     if lock_api.is_object_locked(data.id, request.user):
         message = Message(
-            messages.ERROR, "The " + get_data_label() + " is locked. You can't edit it."
+            messages.ERROR,
+            "The " + get_data_label() + " is locked. You can't edit it.",
         )
         return HttpResponseBadRequest(
             json.dumps({"message": message.message, "tags": message.tags}),
@@ -551,11 +606,23 @@ def edit_record(request):
             data.id, request.user
         )
     except DoesNotExist:
-        template = template_api.get(str(data.template.id), request=request)
+        try:
+            template = template_api.get_by_id(
+                str(data.template.id), request=request
+            )
+        except AccessControlError:
+            message = Message(
+                messages.ERROR,
+                "Unable to access the template for this data: Access forbidden.",
+            )
+            return HttpResponseBadRequest(
+                json.dumps({"message": message.message, "tags": message.tags}),
+                content_type="application/json",
+            )
         # Create a new curate data structure
         curate_data_structure = CurateDataStructure(
             user=str(request.user.id),
-            template=str(template.id),
+            template=template,
             name=data.title,
             form_string=data.xml_content,
             data=data,
@@ -564,16 +631,17 @@ def edit_record(request):
             curate_data_structure = curate_data_structure_api.upsert(
                 curate_data_structure, request.user
             )
-        except ModelError as e:
+        except ModelError:
             message = Message(
                 messages.ERROR,
-                f"Unable to edit the {get_data_label()}. Please check that a {get_form_label()} with the same name does not already exist.",
+                f"Unable to edit the {get_data_label()}. Please check that a {get_form_label()}"
+                f" with the same name does not already exist.",
             )
             return HttpResponseBadRequest(
                 json.dumps({"message": message.message, "tags": message.tags}),
                 content_type="application/json",
             )
-    except Exception as e:
+    except Exception:
         message = Message(messages.ERROR, "A problem occurred while editing.")
         return HttpResponseBadRequest(
             json.dumps({"message": message.message, "tags": message.tags}),
@@ -582,7 +650,11 @@ def edit_record(request):
 
     return HttpResponse(
         json.dumps(
-            {"url": reverse("core_curate_enter_data", args=(curate_data_structure.id,))}
+            {
+                "url": reverse(
+                    "core_curate_enter_data", args=(curate_data_structure.id,)
+                )
+            }
         ),
         content_type="application/javascript",
     )
